@@ -1,7 +1,7 @@
 #########################################################################################
 # Package        HiPi::Interface::MS5611
 # Description  : Interface to MS5611_01BA03 barometric pressure sensor
-# Copyright    : Copyright (c) 2013-2017 Mark Dootson
+# Copyright    : Copyright (c) 2013-2020 Mark Dootson
 # License      : This is free software; you can redistribute it and/or modify it under
 #                the same terms as the Perl 5 programming language system itself.
 #########################################################################################
@@ -12,12 +12,12 @@ package HiPi::Interface::MS5611;
 
 use strict;
 use warnings;
-use parent qw( HiPi::Interface );
+use parent qw( HiPi::Interface::Common::Weather );
 use HiPi qw( :i2c :rpi :ms5611);
 use HiPi::RaspberryPi;
 use Carp;
 
-our $VERSION ='0.81';
+our $VERSION ='0.82';
 
 __PACKAGE__->create_accessors( qw( backend crc) );
 
@@ -191,21 +191,9 @@ sub read_pressure_temp {
     
     my $P = ( ($D1 * $SENS) / (2**21) - $OFF ) / ( 2**15 );
         
-    return ( $P / 100, $TEMP / 100 );
+    return ( sprintf('%.4f', $P / 100), sprintf('%.2f', $TEMP / 100 ) );
 }
 
-sub sea_level_pressure {
-    my( $class, $pressure, $altitude, $temperature, $gravity) = @_;
-    $gravity ||= 9.81;   # acceleration due to gravity
-    my $dgc    = 287.0; # dry gas constant
-    
-    # Po = ((P * 1000) * Math.exp((g*Zg)/(Rd *  (Tv_avg + 273.15))))/1000;
-    
-    my $result = (($pressure * 1000) * exp(($gravity * $altitude)/($dgc *  ($temperature + 273.15))))/1000;
-    
-    $result = sprintf("%.2f", $result);
-    return $result;
-}
 
 1;
 
